@@ -604,4 +604,7 @@ __name__ = "none"
 __file__ = "none"
 __doc__ = "none"
 __package__ = "none"
+NotImplemented = None
 
+def print(obj, sep='', end='\n', file=open()):
+    pass
